@@ -21,7 +21,7 @@ pub struct Options {
     short = 'k',
     long,
     conflicts_with("private_key_path"),
-    env = "TAURI_PRIVATE_KEY"
+    env = "TAURI_SIGNING_PRIVATE_KEY"
   )]
   private_key: Option<String>,
   /// Load the private key from a file
@@ -29,17 +29,50 @@ pub struct Options {
     short = 'f',
     long,
     conflicts_with("private_key"),
-    env = "TAURI_PRIVATE_KEY_PATH"
+    env = "TAURI_SIGNING_PRIVATE_KEY_PATH"
   )]
   private_key_path: Option<PathBuf>,
   /// Set private key password when signing
-  #[clap(short, long, env = "TAURI_PRIVATE_KEY_PASSWORD")]
+  #[clap(short, long, env = "TAURI_SIGNING_PRIVATE_KEY_PASSWORD")]
   password: Option<String>,
   /// Sign the specified file
   file: PathBuf,
 }
 
+// Backwards compatibility with old env vars
+// TODO: remove in v3.0
+fn backward_env_vars(mut options: Options) -> Options {
+  let get_env = |old, new| {
+    if let Ok(old_value) = std::env::var(old) {
+      println!(
+      "\x1b[33mWarning: The environment variable '{old}' is deprecated. Please use '{new}' instead.\x1b[0m",
+    );
+      Some(old_value)
+    } else {
+      None
+    }
+  };
+
+  options.private_key = options
+    .private_key
+    .or_else(|| get_env("TAURI_PRIVATE_KEY", "TAURI_SIGNING_PRIVATE_KEY"));
+
+  options.private_key_path = options.private_key_path.or_else(|| {
+    get_env("TAURI_PRIVATE_KEY_PATH", "TAURI_SIGNING_PRIVATE_KEY_PATH").map(PathBuf::from)
+  });
+
+  options.password = options.password.or_else(|| {
+    get_env(
+      "TAURI_PRIVATE_KEY_PASSWORD",
+      "TAURI_SIGNING_PRIVATE_KEY_PASSWORD",
+    )
+  });
+  options
+}
+
 pub fn command(mut options: Options) -> Result<()> {
+  options = backward_env_vars(options);
+
   options.private_key = if let Some(private_key) = options.private_key_path {
     Some(std::fs::read_to_string(Path::new(&private_key)).expect("Unable to extract private key"))
   } else {
