@@ -1,11 +1,17 @@
-// Copyright 2019-2023 Tauri Programme within The Commons Conservancy
+// Copyright 2019-2024 Tauri Programme within The Commons Conservancy
 // SPDX-License-Identifier: Apache-2.0
 // SPDX-License-Identifier: MIT
 
 #![cfg_attr(not(debug_assertions), windows_subsystem = "windows")]
 
+#[tauri::command]
+fn greet(name: &str) -> String {
+  format!("Hello {name}, You have been greeted from Rust!")
+}
+
 fn main() {
   tauri::Builder::default()
+    .invoke_handler(tauri::generate_handler![greet])
     .run(tauri::generate_context!(
       "../../examples/helloworld/tauri.conf.json"
     ))
